<?xml version="1.0"?>
<!DOCTYPE  rdf:RDF [<!ENTITY xsd "http://www.w3.org/2001/XMLSchema#">
<!ENTITY ma-ont "http://www.w3.org/ns/ma-ont#">]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:ebu="http://ebu.org/nar-extensions/"
  xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:ma-ont="http://www.w3.org/ns/ma-ont#"
  xmlns:owl="http://www.w3.org/2002/07/owl#" xmlns:default="urn:ebu:metadata-schema:ebuCore_2011"
  xsi:schemaLocation="EBU_CORE_20110531.xsd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

  <xsl:output method="xml" encoding="UTF-8" indent="yes" omit-xml-declaration="no"/>

  <xsl:template match="@*">
    <xsl:copy/>
  </xsl:template>

  <xsl:template match="text() | comment()">
    <xsl:copy/>
  </xsl:template>

  <xsl:template match="*">
    <xsl:element name="{name()}">
      <xsl:apply-templates select="* | text() | @* | comment()"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="default:part">
    <xsl:param name="filepath"/>
    <xsl:param name="keyframepath"/>
    
    <!-- Fragment declaration -->
    <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
    <xsl:value-of select="concat($filepath,/default:ebuCoreMain/default:coreMetadata/default:format[@formatName='manifestation']/@formatId,'#',default:identifier[@typeLabel='partId']/dc:identifier)"/>
    <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
    <rdf:type rdf:resource="&ma-ont;MediaFragment"/>
    <ma-ont:fragmentName rdf:datatype="&xsd;string">
      <xsl:value-of
        select="default:description[@typeLabel='sequenceNumber' and dc:description!='']/dc:description"
      />
    </ma-ont:fragmentName>

    <!-- Defining the URI/locator of the fragment by computing the start and end tags for the part. start tag = part 'start'. end tag = next fragment 'start' minus one frame bfroe conversion in seconds with corrected edit rate, 
      if no following fragment i.e. for last fragment, locator = www.hhh.cc/t=start, ...empty... which means to the end of the file, see MFWG fragment URI -->
    <xsl:variable name="endtag">
      <xsl:choose>
        <xsl:when test="position() &lt;last()">
          <xsl:variable name="increment" select="position()+1"/>
          <xsl:value-of
            select="((ancestor-or-self::default:coreMetadata/default:part[position()=$increment]/default:format[@formatName='partId']/default:start/default:editUnitNumber - 1)
            div  ancestor-or-self::default:coreMetadata/default:part[position()=$increment]/default:format[@formatName='partId']/default:start/default:editUnitNumber/@editRate)
            * ancestor-or-self::default:coreMetadata/default:part[position()=$increment]/default:format[@formatName='partId']/default:start/default:editUnitNumber/@factorNumerator
            div ancestor-or-self::default:coreMetadata/default:part[position()=$increment]/default:format[@formatName='partId']/default:start/default:editUnitNumber/@factorDenominator"
          />
        </xsl:when>
        <xsl:otherwise> </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="starttag">
      <xsl:value-of
        select="default:format[@formatName='partId']/default:start/default:editUnitNumber 
        div (default:format[@formatName='partId']/default:start/default:editUnitNumber/@editRate 
        * default:format[@formatName='partId']/default:start/default:editUnitNumber/@factorNumerator 
        div default:format[@formatName='partId']/default:start/default:editUnitNumber/@factorDenominator)"
      />
    </xsl:variable>
    <ma-ont:locator rdf:datatype="&xsd;anyURI">
      <xsl:value-of select="concat($filepath,/default:ebuCoreMain/default:coreMetadata/default:format[@formatName='manifestation']/@formatId,'/','t=',$starttag,',',$endtag)"/>
    </ma-ont:locator>

    <!-- PART ICON -->
    <xsl:for-each select="default:format">
      <xsl:if test="@formatName = 'thumbnail'">
        <xsl:for-each select="default:locator">
          <xsl:if test="@typeLabel='thumbnail' and string-length(self::default:locator)!=0">
            <xsl:variable name="var5">
              <xsl:value-of select="concat($keyframepath,substring-after(self::default:locator,'//'))"/>
            </xsl:variable>
            <xsl:variable name="var6">
              <xsl:value-of select="substring-before($var5, '.jpeg')"/>
            </xsl:variable>
            <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasRelatedImage rdf:resource="</xsl:text>
            <xsl:value-of select=" $var6"/>
            <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>

    <!-- PART DESCRIPTION OTHER THAN SEQUENCE NUMBER -->
    <xsl:for-each select="default:description">
      <xsl:if test="string-length(default:description)!=0 and @typeLabel!='sequenceNumber'">
        <ma-ont:description rdf:datatype="&xsd;string" xml:lang="en">
          <xsl:value-of select="default:description"/>
        </ma-ont:description>
      </xsl:if>
    </xsl:for-each>

    <!-- PART IDENTIFIER -->
    <xsl:for-each select="default:identifier">
      <xsl:if test="string-length(dc:identifier)!=0">
        <ma-ont:identifier rdf:datatype="&xsd;anyURI">
          <xsl:value-of select="dc:identifier"/>
        </ma-ont:identifier>
      </xsl:if>
    </xsl:for-each>

    <!-- PART LANGUAGE -->
    <xsl:for-each select="default:language">
      <xsl:if test="string-length(dc:language)!=0">
        <ma-ont:hasLanguage>
        <owl:Thing>
        <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
        <xsl:value-of select="dc:language"/>
        </rdfs:label>
        </owl:Thing>
        </ma-ont:hasLanguage>
        </xsl:if>
    </xsl:for-each>

    <!-- CLOSE PART DESCRIPTION -->
    <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>

    <!-- DEFINE PART THUMBNAIL CLASSES -->
    <xsl:for-each select="default:format/default:locator">
      <xsl:if test="@typeLabel='thumbnail' and string-length(self::default:locator)!=0">
        <xsl:variable name="var5">
          <xsl:value-of select="substring-after(self::default:locator,'//')"/>
        </xsl:variable>
        <xsl:variable name="var6">
          <xsl:value-of select="substring-before($var5, '.jpeg')"/>
        </xsl:variable>
        <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
        <xsl:value-of select="concat($keyframepath, $var6)"/>
        <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
        <rdf:type rdf:resource="&ma-ont;Image"/>
        <ma-ont:locator rdf:datatype="&xsd;anyURI">
          <xsl:value-of select="concat($keyframepath,self::default:locator)"/>
        </ma-ont:locator>
        <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  <xsl:template match="/">

    <rdf:RDF xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
      xmlns:owl="http://www.w3.org/2002/07/owl#" xmlns:ma-ont="http://www.w3.org/ns/ma-ont#"
      xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
      xmlns:EBUNMSSRVCodeSource="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSSRVCodeSource#"
      xmlns:EBUNMSSRVCodeSource2="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSSRVCodeSource2#"
      xmlns:EBUNMSSRVCodeSource3="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSSRVCodeSource3#"
      xmlns:EBUNMSSRVCodeSource4="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSSRVCodeSource4#"
      xmlns:EBUNMSSRVCodeOrigin="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSSRVCodeOrigin#"
      xmlns:EBUNMSClassCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSClassCode#"
      xmlns:EBUNMSCategoryCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSCategoryCode#"
      xmlns:EBUNMSWebcatCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSWebcatCode#"
      xmlns:EBUNMSStatusCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSStatusCode#"
      xmlns:EBUNMSGenreCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSGenreCode#"
      xmlns:EBUNMSTargetAudienceCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSTargetAudienceCode#"
      xmlns:EBUNMSRatingCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSRatingCode#"
      xmlns:EBUNMSDescription="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSDescription#"
      xmlns:EBUNMSCityCode="http://www.ebu.ch/metadata/ontologies/skos/EBUNMSCityCode#"
      xmlns:EBUServicerCode="http://www.ebu.ch/metadata/ontologies/skos/EBUServicerCode#"
      xmlns:EBURightsHolderCode="http://www.ebu.ch/metadata/ontologies/skos/EBURightsHolderCode#"
      xmlns:EBUProviderCode="http://www.ebu.ch/metadata/ontologies/skos/EBUProviderCode#"
      xmlns:EBULanguageUsageCode="http://www.ebu.ch/metadata/ontologies/skos/EBULanguageUsageCode#"
      xmlns:EBULanguageCode="http://www.ebu.ch/metadata/ontologies/skos/EBULanguageCode#">
      <rdf:Description rdf:about="">
        <owl:imports rdf:resource="http://www.w3.org/ns/ma-ont"/>
        <rdf:type rdf:resource="http://www.w3.org/2002/07/owl#Ontology"/>
      </rdf:Description>
      <xsl:for-each select="default:ebuCoreMain/default:coreMetadata">
        <xsl:variable name="mainId">
          <!-- RESOURCE ID : IDENTIFIER of TYPE itemId  -->
          <xsl:for-each select="default:identifier">
            <xsl:if test="@typeLabel='itemId'">
              <xsl:value-of select="dc:identifier"/>
            </xsl:if>
          </xsl:for-each>
        </xsl:variable>

        <!-- WEB PUBLICATION LOCATOR PATH -->
        <xsl:variable name="webdocpath">
          <xsl:for-each select="default:format">
            <xsl:if test="@formatName='dopesheet'">
              <xsl:value-of
                select="concat('http://www.dummy.ch',substring-before(default:locator,'index.html'))"
              />
            </xsl:if>
          </xsl:for-each>
        </xsl:variable>
        <!-- CONTENT FILE LOCATOR PATH -->
        <xsl:variable name="filepath">
          <xsl:variable name="var13" select="substring-before($webdocpath,'Items')"/>
          <xsl:variable name="var14" select="substring-after($webdocpath,'Items')"/>
          <xsl:value-of select="concat($var13,'File',$var14)"/>
        </xsl:variable>
        <!-- THUMBNAIL FILE LOCATOR PATH -->
        <xsl:variable name="keyframepath">
          <xsl:variable name="var13" select="substring-before($webdocpath,'Items')"/>
          <xsl:variable name="var14" select="substring-after($webdocpath,'Items')"/>
          <xsl:value-of select="concat($var13,'keyframe',$var14)"/>
        </xsl:variable>

        <!-- MEDIA RESOURCE (NEWS - example based on EVN nml2XML to ebucoreXML transform) ITEM AND DOPESHEET-->
        <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
        <xsl:value-of select="$mainId"/>
        <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
        <rdf:type rdf:resource="&ma-ont;MediaResource"/>
        <ma-ont:identifier rdf:datatype="&xsd;anyURI">
          <xsl:value-of select="$mainId"/>
        </ma-ont:identifier>
        <!-- TITLE -->
        <xsl:for-each select="default:title">
          <xsl:if test="string-length(dc:title)!=0">
            <ma-ont:title rdf:datatype="&xsd;string" xml:lang="en">
              <xsl:value-of select="dc:title"/>
            </ma-ont:title>
          </xsl:if>
        </xsl:for-each>
        <!-- ALTERNATIVE TITLE -->
        <xsl:for-each select="default:alternativeTitle">
          <xsl:if test="string-length(dc:title)!=0">
            <ma-ont:alternativeTitle rdf:datatype="&xsd;string" xml:lang="en">
              <xsl:value-of select="dc:title"/>
            </ma-ont:alternativeTitle>
          </xsl:if>
        </xsl:for-each>
        <!-- CREATOR -->
        <xsl:for-each select="default:creator">
          <xsl:choose>
            <xsl:when test="@entityId!=''">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasCreator rdf:resource="</xsl:text>
              <xsl:value-of select="@entityId"/>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <ma-ont:hasCreator>
                <xsl:if test="default:organisationDetails">
                  <ma-ont:Organisation>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="default:organisationDetails/organisationName"/>
                    </rdfs:label>
                  </ma-ont:Organisation>
                </xsl:if>
                <xsl:if test="default:contactDetails">
                  <ma-ont:Person>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="default:contactDetails/default:name"/>
                    </rdfs:label>
                  </ma-ont:Person>
                </xsl:if>
              </ma-ont:hasCreator>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <!-- SUBJECT / KEYWORD -->
        <xsl:for-each select="default:subject">
          <xsl:if test="string-length(default:subjectCode)!=0 or string-length(dc:subject)!=0">
            <xsl:choose>
              <xsl:when test="string-length(default:subjectCode)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasKeyword rdf:resource="</xsl:text>
                <xsl:value-of select="default:subjectCode"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <ma-ont:hasKeyword>
                  <owl:Thing>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="dc:subject"/>
                    </rdfs:label>
                  </owl:Thing>
                </ma-ont:hasKeyword>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </xsl:for-each>
        <!-- DESCRIPTION -->
        <xsl:for-each select="default:description">
          <xsl:if test="dc:description!=''">
            <ma-ont:description rdf:datatype="&xsd;string" xml:lang="en">
              <xsl:value-of select="dc:description"/>
            </ma-ont:description>
          </xsl:if>
        </xsl:for-each>
        <!-- PROVIDER -->
        <xsl:for-each select="default:publisher">
          <xsl:choose>
            <xsl:when test="string-length(@entityId)!=0">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasPublisher rdf:resource="</xsl:text>
              <xsl:value-of select="@entityId"/>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:if test="string-length(default:name)!=0">
                <ma-ont:hasPublisher>
                  <xsl:if test="default:organisationDetails">
                    <ma-ont:organisation>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:organisationDetails/default:organisationName"
                        />
                      </rdfs:label>
                    </ma-ont:organisation>
                  </xsl:if>
                  <xsl:if test="default:contactDetails">
                    <ma-ont:Person>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:contactDetails/default:name"/>
                      </rdfs:label>
                    </ma-ont:Person>
                  </xsl:if>
                </ma-ont:hasPublisher>
              </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <!-- CONTRIBUTOR -->
        <xsl:for-each select="default:contributor">
          <xsl:choose>
            <xsl:when test="string-length(@entityId)!=0">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasContributor rdf:resource="</xsl:text>
              <xsl:value-of select="@entityId"/>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <ma-ont:hasContributor>
                <xsl:if test="default:organisationDetails">
                  <ma-ont:Organisation>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="default:organisationDetails/default:organisationName"/>
                    </rdfs:label>
                  </ma-ont:Organisation>
                </xsl:if>
                <xsl:if test="default:contactDetails">
                  <ma-ont:Person>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="default:contactDetails/default:name"/>
                    </rdfs:label>
                  </ma-ont:Person>
                </xsl:if>
              </ma-ont:hasContributor>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <!-- GENRE -->
        <xsl:for-each select="default:type/default:genre">
          <xsl:choose>
            <xsl:when test="@typeLink!=''">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasGenre rdf:resource="</xsl:text>
              <xsl:value-of select="@typeLink"/>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <ma-ont:hasGenre>
                <owl:Thing>
                  <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                    <xsl:value-of select="@typeLabel"/>
                  </rdfs:label>
                </owl:Thing>
              </ma-ont:hasGenre>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <!-- TARGET AUDIENCE CLASS -->
        <xsl:for-each select="default:type/default:targetAudience">
          <xsl:choose>
            <xsl:when test="@typeLink!=''">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasTargetAudience rdf:resource="</xsl:text>
              <xsl:value-of select="@typeLink"/>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <ma-ont:hasTargetAudience>
                <owl:Thing>
                  <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                    <xsl:value-of select="@typeLabel"/>
                  </rdfs:label>
                </owl:Thing>
              </ma-ont:hasTargetAudience>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
        <!--DATES -->
        <xsl:for-each select="default:date">
          <xsl:if
            test="string-length(default:created/@startTime)!=0 or string-length(default:created/@startDate)!=0">
            <ma-ont:creationDate rdf:datatype="&xsd;dateTime">
              <xsl:choose>
                <xsl:when
                  test="string-length(default:created/@startTime)!=0 and string-length(default:created/@startDate)!=0">
                  <xsl:value-of
                  select="concat(default:created/@startDate,'T',default:created/@startTime)"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:if
                    test="string-length(default:created/@startTime)=0 and string-length(default:created/@startDate)!=0">
                    <xsl:value-of select="default:created/@startDate"/>
                  </xsl:if>
                  <xsl:if
                    test="string-length(default:created/@startDate)=0 and string-length(default:created/@startTime)!=0">
                    <xsl:value-of select="default:created/@startTime"/>
                  </xsl:if>
                </xsl:otherwise>
              </xsl:choose>
            </ma-ont:creationDate>
          </xsl:if>
          <xsl:if
            test="string-length(default:modified/@startTime)!=0 or string-length(default:modified/@startDate)!=0">
            <ma-ont:editDate rdf:datatype="&xsd;dateTime">
              <xsl:choose>
                <xsl:when
                  test="string-length(default:modified/@startTime)!=0 and string-length(default:modified/@startDate)!=0">
                  <xsl:value-of
                    select="concat(default:modified/@startDate,'T',default:modified/@startTime)"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:if
                    test="string-length(default:modified/@startTime)=0 and string-length(default:modified/@startDate)!=0 ">
                    <xsl:value-of select="default:modified/@startDate"/>
                  </xsl:if>
                  <xsl:if
                    test="string-length(default:modified/@startDate)=0 and string-length(default:modified/@startTime)!=0">
                    <xsl:value-of select="default:modified/@startTime"/>
                  </xsl:if>
                </xsl:otherwise>
              </xsl:choose>
            </ma-ont:editDate>
          </xsl:if>
          <xsl:if
            test="string-length(default:issued/@startTime)!=0 or string-length(default:issued/@startDate)!=0">
            <ma-ont:releaseDate rdf:datatype="&xsd;dateTime">
              <xsl:choose>
                <xsl:when
                  test="string-length(default:issued/@startTime)!=0 and string-length(default:issued/@startDate)!=0">
                  <xsl:value-of
                    select="concat(default:issued/@startDate,'T',default:issued/@startTime)"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:if
                    test="string-length(default:issued/@startTime)=0 and string-length(default:issued/@startDate)!=0">
                    <xsl:value-of select="default:issued/@startDate"/>
                  </xsl:if>
                  <xsl:if
                    test="string-length(default:issued/@startDate)=0 and string-length(default:issued/@startTime)!=0">
                    <xsl:value-of select="default:issued/@startTime"/>
                  </xsl:if>
                </xsl:otherwise>
              </xsl:choose>
            </ma-ont:releaseDate>
          </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='dopesheet'">
            <ma-ont:locator rdf:datatype="&xsd;anyURI">
              <!--xsl:value-of select="default:locator"/-->
              <xsl:value-of select="concat($webdocpath,'index.html')"/>
            </ma-ont:locator>
          </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='thumbnail'">
            <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasRelatedImage rdf:resource="</xsl:text>
            <xsl:value-of select="@formaId"/>
            <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            <!--ma-ont:hasRelatedImage>
              <xsl:value-of select="formatId"/>
            </ma-ont:hasRelatedImage-->
          </xsl:if>
        </xsl:for-each>
        <xsl:for-each select="default:identifier">
          <!--ma-ont:identifier>
            <xsl:value-of select="default:identifier/dc:identifier"/>
          </ma-ont:identifier-->
        </xsl:for-each>
        <!-- LANGUAGE -->
        <xsl:for-each select="default:language">
          <xsl:if test="string-length(dc:language)!=0">
                <ma-ont:hasLanguage>
                  <owl:Thing>
                    <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                      <xsl:value-of select="dc:language"/>
                    </rdfs:label>
                  </owl:Thing>
                </ma-ont:hasLanguage>
          </xsl:if>
        </xsl:for-each>
        <!-- LOCATED -->
        <xsl:for-each select="default:coverage/default:spatial">
          <xsl:for-each select="default:location">
            <xsl:choose>
              <xsl:when test="string-length(@locationId)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:createdIn rdf:resource="</xsl:text>
                <xsl:value-of select="locationId"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="@typeLink='cptype:city'">
                  <xsl:text disable-output-escaping="yes">&lt;ma-ont:createdIn rdf:resource="</xsl:text>
                  <xsl:value-of select="concat('EBUNMSCityCode:',translate(default:name,' ',''))"/>
                  <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:for-each>
        </xsl:for-each>
        <!-- RIGHTS USAGE TERMS -->
        <xsl:for-each select="default:rights">
          <xsl:if test="@typeLabel='UsageRights'">
            <xsl:choose>
              <xsl:when test="string-length(rightsLink)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasAccessConditions rdf:resource="</xsl:text>
                <xsl:value-of select="default:rightsLink"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="string-length(dc:rights)!=0">
                  <ma-ont:hasAccessConditions>
                    <owl:Thing>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="dc:rights"/>
                      </rdfs:label>
                    </owl:Thing>
                  </ma-ont:hasAccessConditions>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </xsl:for-each>
        <!-- RIGHTS COPYRIGHT NOTICE -->
        <xsl:for-each select="default:rights">
          <xsl:if test="@typeLabel='CopyrightNotice'">
            <xsl:choose>
              <xsl:when test="string-length(rightsLink)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:haspolicy rdf:resource="</xsl:text>
                <xsl:value-of select="default:rightsLink"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="string-length(dc:rights)!=0">
                  <ma-ont:copyrightNotice rdf:datatytpe="&xsd;string" xml:lang="en">
                    <xsl:value-of select="dc:rights"/>
                  </ma-ont:copyrightNotice>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </xsl:for-each>
        <!-- COPYRIGHTHOLDER -->
        <xsl:for-each select="default:rights">
          <xsl:for-each select="default:rightsHolder">
            <xsl:choose>
              <xsl:when test="string-length(@entityId)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:isCopyrightedBy rdf:resource="</xsl:text>
                <xsl:value-of select="@entityId"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="default:organisationDetails or default:personDetails">
                  <ma-ont:isCopyrightedBy>
                    <xsl:if
                      test="default:organisationDetails and string-length(default:organisationDetails/default:organisationName)!=0">
                      <ma-ont:Organisation>
                        <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                          <xsl:value-of
                            select="default:organisationDetails/default:organisationName"/>
                        </rdfs:label>
                      </ma-ont:Organisation>
                    </xsl:if>
                    <xsl:if
                      test="default:personDetails and string-length(default:personDetails/default:name)!=0">
                      <ma-ont:Person>
                        <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                          <xsl:value-of select="default:personDetails/default:name"/>
                        </rdfs:label>
                      </ma-ont:Person>
                    </xsl:if>
                  </ma-ont:isCopyrightedBy>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:for-each>
        </xsl:for-each>
        <!-- RELATED RESOURCE / MANIFESTATION / VIDEO-AUDIO FILE-->
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='manifestation'">
            <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasSource rdf:resource="</xsl:text>
            <xsl:value-of select="concat($filepath,@formatId)"/>
            <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
          <!-- duplicate with relation only for ma-ont -->
            <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasRelatedResource rdf:resource="</xsl:text>
            <xsl:value-of select="concat($filepath,@formatId)"/>
            <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- COLLECTION -->
        <xsl:for-each select="default:isMemberOf">
          <xsl:text disable-output-escaping="yes">&lt;ma-ont:isMemberOf rdf:resource="</xsl:text>
          <xsl:value-of select="substring-before($webdocpath,'/2011')"/>
          <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
        </xsl:for-each>
<xsl:for-each select="default:rating">
  <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasRating rdf:resource="</xsl:text>
  <xsl:value-of select="concat(@formatLabel,':',default:ratingValue)"/>
  <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
</xsl:for-each>
        
        <!-- CLOSE ITEM DESCRIPTION -->
        <xsl:text disable-output-escaping="yes"> &lt;/rdf:Description&gt;</xsl:text>

        <!-- COLLECTION CLASS  -->
        <xsl:for-each select="default:isMemberOf">
          <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
          <xsl:value-of select="substring-before($webdocpath,'/2011')"/>
          <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
          <rdf:type rdf:resource="&ma-ont;Collection"/>
          <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
        </xsl:for-each>
        

        <!-- REMOTE CONTENT - SOURCE CLASS DEFINITION -->
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='manifestation'">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="concat($filepath,@formatId)"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="&ma-ont;MediaResource"/>
            <!-- HASFRAGMENT -->
            <xsl:for-each select="following-sibling::default:part">
              <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasFragment rdf:resource="</xsl:text>
              <xsl:for-each select="default:identifier">
                <xsl:if test="@typeLabel='partId'">
                  <xsl:value-of select="concat($filepath,/default:ebuCoreMain/default:coreMetadata/default:format[ @formatName='manifestation']/@formatId,'#',dc:identifier)"/>
                </xsl:if>
              </xsl:for-each>
              <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
            </xsl:for-each>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>

        <!-- PART META -->
        <xsl:apply-templates select="default:part">
          <xsl:with-param name="filepath" select="$filepath"/>
          <xsl:with-param name="keyframepath" select="$keyframepath"/>
        </xsl:apply-templates>

        <!-- DEFINE  CLASSES / RESOURCES FOR THE ITEM -->
        <!-- RATING CLASS -->
        
        <xsl:for-each select="default:rating">
          <xsl:if test="string-length(@formatLabel)!=0 and string-length(default:ratingValue)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="concat(@formatLabel,':',default:ratingValue)"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="&ma-ont;Rating"/>
            <ma-ont:hasRatingSystem>
              <owl:Thing>
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="@formatLabel"/>
              </rdfs:label>
              </owl:Thing>
            </ma-ont:hasRatingSystem>
            <ma-ont:ratingValue rdf:datatype="&xsd;decimal" xml:lang="en">
              <xsl:value-of select="default:ratingValue"/>
            </ma-ont:ratingValue>
            <ma-ont:ratingScaleMax rdf:datatype="&xsd;decimal" xml:lang="en">
              <xsl:value-of select="default:ratingScaleMaxValue"/>
            </ma-ont:ratingScaleMax>
            <ma-ont:ratingScaleMin rdf:datatype="&xsd;decimal" xml:lang="en">
              <xsl:value-of select="default:ratingScaleMinValue"/>
            </ma-ont:ratingScaleMin>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        
        <!-- LANGUAGE RESOURCE -->
        <xsl:for-each select="default:language">
          <xsl:if test="string-length(@typeLink)!=0 and string-length(dc:language)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="concat('EBULanguageCode:',dc:language)"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="http://www.w3.org/2002/07/owl#Thing"/>
            <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
              <xsl:value-of select="dc:language"/>
            </rdfs:label>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>

        <!-- GENRE RESOURCE -->
        <xsl:for-each select="default:type/default:genre">
          <xsl:if test="string-length(@typeLink)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="@typeLink"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="http://www.w3.org/2002/07/owl#Thing"/>
            <xsl:if test="string-length(@typeLabel)!=0">
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="@typeLabel"/>
              </rdfs:label>
            </xsl:if>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>

        <!-- TARGET AUDIENCE CLASS -->
        <xsl:for-each select="default:type/default:targetAudience">
          <xsl:if test="string-length(@typeLink)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="@typeLink"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="&ma-ont;TargetAudience"/>
            <xsl:if test="string-length(@typeLabel)!=0">
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="@typeLabel"/>
              </rdfs:label>
            </xsl:if>
            <ma-ont:hasClassification>
            <owl:Thing>
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                all
              </rdfs:label>
            </owl:Thing>
            </ma-ont:hasClassification>
            <ma-ont:hasClassificationSystem>
            <owl:Thing>
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                EBU internal target audience code
              </rdfs:label>
              </owl:Thing>
            </ma-ont:hasClassificationSystem>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        

        <!-- DEFINE ICON THUMBNAIL CLASSES -->
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='thumbnail'">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="concat($filepath,@formatId)"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="&ma-ont;Image"/>
            <ma-ont:locator rdf:datatype="&xsd;anyURI">
              <xsl:value-of select="default:locator"/>
            </ma-ont:locator>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>

        <!-- MEDIA RESOURCE NEWS ITEM / VIDEO ITEM-->
        <xsl:for-each select="default:format">
          <xsl:if test="@formatName='manifestation'">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="concat($filepath,@formatId)"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="&ma-ont;MediaResource"/>
            <xsl:choose>
              <xsl:when test="string-length(default:fileFormat/@typeLink)!=0">
                <xsl:text disable-output-escaping="yes">&lt;ma-ont:hasFormat rdf:resource="</xsl:text>
                <xsl:value-of select="default:fileFormat/@typeLink"/>
                <xsl:text disable-output-escaping="yes">"/&gt;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="string-length(default:fileFormat/@typeLabel)!=0">
                  <ma-ont:hasFormat>
                    <owl:Thing>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:fileFormat/@typeLabel"/>
                      </rdfs:label>
                    </owl:Thing>
                  </ma-ont:hasFormat>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
            <ma-ont:frameWidth rdf:datatype="&xsd;integer">
              <xsl:value-of select="default:videoFormat/default:width"/>
            </ma-ont:frameWidth>
            <ma-ont:frameHeight rdf:datatype="&xsd;integer">
              <xsl:value-of select="default:videoFormat/default:height"/>
            </ma-ont:frameHeight>
            <ma-ont:hasCompression>
              <owl:Thing>
              <rdfs:label  rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="default:videoFormat/default:videoEncoding/@typeLabel"/>
              </rdfs:label>
              </owl:Thing>
            </ma-ont:hasCompression>
            <ma-ont:samplingRate rdf:datatype="&xsd;decimal">
  <xsl:value-of select="default:audioFormat/default:technicalAttributeFloat[@typeLabel='samplingRate']"/>
</ma-ont:samplingRate>
            
            <ma-ont:averageBitRate rdf:datatype="&xsd;decimal">
              <xsl:value-of select="default:technicalAttributeFloat[@typeLabel='averageBitRate']"/>
            </ma-ont:averageBitRate>
            <ma-ont:numberOfTracks rdf:datatype="&xsd;integer">
              <xsl:value-of select="default:technicalAttributeFloat[@typeLabel='numOfTracks']"/>
            </ma-ont:numberOfTracks>
            <ma-ont:frameRate rdf:datatype="&xsd;decimal">
              <xsl:if
                test=" string-length(default:duration/default:editUnitNumber/@editRate)!=0">
                <xsl:value-of
                  select="default:duration/default:editUnitNumber/@editRate * default:duration/default:editUnitNumber/@factorNumerator div default:duration/default:editUnitNumber/@factorDenominator"
                />
              </xsl:if>
            </ma-ont:frameRate>
            <ma-ont:duration rdf:datatype="&xsd;decimal">
              <xsl:choose>
                <xsl:when test="default:duration/default:editUnitNumber">
                  <xsl:variable name="editrate">
                    <xsl:value-of
                      select="default:duration/default:editUnitNumber/@editRate * default:duration/default:editUnitNumber/@factorNumerator div default:duration/default:editUnitNumber/@factorDenominator"
                    />
                  </xsl:variable>
                  <xsl:value-of select="default:duration div $editrate"/>
                </xsl:when>
                <xsl:when test="default:duration/default:timecode"> tbd </xsl:when>
                <xsl:when test="default:duration/default:normalPlayTime"> tbd
                </xsl:when>
                </xsl:choose>
            </ma-ont:duration>

            <ma-ont:locator rdf:datatype="&xsd;anyURI">
              <!--xsl:value-of select="default:locator"/-->
              <xsl:value-of select="$filepath"/>
            </ma-ont:locator>

            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>

        <!-- DEFINITION CREATOR CLASS -->
        <xsl:for-each select="default:creator">
          <xsl:if test="string-length(@entityId)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="@entityId"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <xsl:choose>
              <xsl:when test="default:organisationDetails or contains(@qcode,'EBUNMSSRVCode')">
                <rdf:type rdf:resource="&ma-ont;Organisation"/>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:organisationDetails/default:organisationName"/>
                </rdfs:label>
              </xsl:when>
              <xsl:otherwise>
                <xsl:choose>
                  <xsl:when test="default:contactDetails">
                    <ma-ont:Person>
                      <rdf:type rdf:resource="&ma-ont;Person"/>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:contactDetails/default:name"/>
                      </rdfs:label>
                    </ma-ont:Person>
                  </xsl:when>
                  <xsl:otherwise>
                    <rdf:type rdf:resource="&ma-ont;Agent"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- DEFINE PUBLISHER  CLASS -->
        <xsl:for-each select="default:publisher">
          <xsl:if test="string-length(@entityId)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="@entityId"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <xsl:choose>
              <xsl:when test="default:organisationDetails or contains(@qcode,'EBUNMSSRVCode')">
                <rdf:type rdf:resource="&ma-ont;Organisation"/>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:organisationDetails/default:organisationName"/>
                </rdfs:label>
              </xsl:when>
              <xsl:otherwise>
                <xsl:choose>
                  <xsl:when test="default:contactDetails">
                    <ma-ont:Person>
                      <rdf:type rdf:resource="&ma-ont;Person"/>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:contactDetails/default:name"/>
                      </rdfs:label>
                    </ma-ont:Person>
                  </xsl:when>
                  <xsl:otherwise>
                    <rdf:type rdf:resource="&ma-ont;Agent"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- DEFINE CONTRIBUTOR  CLASS -->
        <xsl:for-each select="default:contributor">
          <xsl:if test="string-length(@entityId)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="@entityId"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <xsl:choose>
              <xsl:when test="default:organisationDetails or contains(@qcode,'EBUNMSSRVCode')">
                <rdf:type rdf:resource="&ma-ont;Organisation"/>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:organisationDetails/default:organisationName"/>
                </rdfs:label>
              </xsl:when>
              <xsl:otherwise>
                <xsl:choose>
                  <xsl:when test="default:contactDetails">
                    <ma-ont:Person>
                      <rdf:type rdf:resource="&ma-ont;Person"/>
                      <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                        <xsl:value-of select="default:contactDetails/default:name"/>
                      </rdfs:label>
                    </ma-ont:Person>
                  </xsl:when>
                  <xsl:otherwise>
                    <rdf:type rdf:resource="&ma-ont;Agent"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- KEYWORD RESOURCE -->
        <xsl:for-each select="default:subject">
          <xsl:if test="string-length(default:subjectCode)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="default:subjectCode"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="http://www.w3.org/2002/07/owl#Thing"/>
            <xsl:if test="string-length(dc:subject)!=0">
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="dc:subject"/>
              </rdfs:label>
            </xsl:if>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- MIMETYPE - FORMAT RESOURCE -->
        <xsl:for-each select="default:format">
          <xsl:if test="string-length(default:fileFormat/@typeLink)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="default:fileFormat/@typeLink"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <rdf:type rdf:resource="http://www.w3.org/2002/07/owl#Thing"/>
            <xsl:if test="string-length(default:fileFormat/@typeLabel)!=0">
              <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                <xsl:value-of select="default:fileFormat/@typeLabel"/>
              </rdfs:label>
            </xsl:if>
            <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
          </xsl:if>
        </xsl:for-each>
        <!-- DEFINE LOCATION CLASSES -->
        <xsl:for-each select="default:coverage/default:spatial">
          <xsl:for-each select="default:location">
            <xsl:if test="@typeLink='cptype:city'">
              <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
              <xsl:value-of select="concat('EBUNMSCityCode:',translate(default:name,' ',''))"/>
              <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
              <rdf:type rdf:resource="&ma-ont;Location"/>
              <xsl:if test="string-length(default:name)!=0">
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:name"/>
                </rdfs:label>
                <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
              </xsl:if>
            </xsl:if>
          </xsl:for-each>
        </xsl:for-each>

        <!-- COPRIGHT NOTICE RESOURCE-->
        <xsl:for-each select="default:rights">
          <xsl:if test="@typeLabel='CopyrightNotice' and string-length(rightsLink)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="default:rightsLink"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <xsl:if test="string-length(dc:rights)!=0">
              <owl:Thing>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="dc:rights"/>
                </rdfs:label>
              </owl:Thing>
            </xsl:if>
          </xsl:if>
        </xsl:for-each>

        <!-- USAGE TERMS RESOURCE -->
        <xsl:for-each select="default:rights">
          <xsl:if test="@typeLabel='UsageRights' and string-length(rightsLink)!=0">
            <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
            <xsl:value-of select="default:rightsLink"/>
            <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
            <xsl:if test="string-length(dc:rights)!=0">
              <owl:Thing>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="dc:rights"/>
                </rdfs:label>
              </owl:Thing>
            </xsl:if>
          </xsl:if>
        </xsl:for-each>

        <!-- DEFINITION COPYRIGHT HOLDER CLASS -->
        <xsl:for-each select="default:rights">
          <xsl:for-each select="default:rightsHolder">
            <xsl:if test="string-length(@entityId)!=0">
              <xsl:text disable-output-escaping="yes">&lt;rdf:Description rdf:about="</xsl:text>
              <xsl:value-of select="@entityId"/>
              <xsl:text disable-output-escaping="yes">"&gt;</xsl:text>
              <xsl:if test="default:organisationDetails or contains(@qcode,'EBUNMSSRVCode')">
                <rdf:type rdf:resource="&ma-ont;Organisation"/>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:organisationDetails/default:organisationName"/>
                </rdfs:label>
              </xsl:if>
              <xsl:if test="default:contactDetails">
                <rdf:type rdf:resource="&ma-ont;Organisation"/>
                <rdfs:label rdf:datatype="&xsd;string" xml:lang="en">
                  <xsl:value-of select="default:contactDetails/default:name"/>
                </rdfs:label>
              </xsl:if>
              <xsl:text disable-output-escaping="yes">&lt;/rdf:Description&gt;</xsl:text>
            </xsl:if>
          </xsl:for-each>
        </xsl:for-each>
      </xsl:for-each>
    </rdf:RDF>
  </xsl:template>
</xsl:stylesheet>
